Plover Stenograph USB
=====================

Use Stenograph Diamanté and Luminex machines on Plover. The plugin may
not work with other machines. If it does, please let me know.

Special thanks to Keith McCready for his guidance and support.

Get the Drivers
---------------

-  On Windows, install the `Stenograph USB Drivers`_ (`direct link`_)
-  On Mac, install `libusb`_
-  On Linux, ensure you have libusb installed

Installation
------------

The plugin is available to install from within Plover 4 using the
Plugins Manager.

.. _Stenograph USB Drivers: http://www.stenograph.com/utilities-links-downloads
.. _direct link: http://www.stenograph.com/content/files/documents/USB_Writer_Drivers.zip
.. _libusb: http://macappstore.org/libusb/
